@@ -156,7 +156,7 @@ conf() {
   --exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
   --libdir=${prefix}/lib --includedir=${prefix}/include \
   --mandir=${prefix}/share/man --infodir=${prefix}/share/info \
-  --libexecdir='${sbindir}' --localstatedir=/var \
+  --libexecdir='${prefix}/sbin' --localstatedir=/var \
   --datadir='${prefix}/share' --disable-gtk-doc --with-x \
   --with-xml-catalog=/etc/xml/catalog )
 }
